@@ -1,5 +1,7 @@
 // -*- tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 // vi: set et ts=4 sw=2 sts=2:
+// SPDX-FileCopyrightInfo: Copyright © DUNE Project contributors, see file LICENSE.md in module root
+// SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-GPL-2.0-only-with-PDELab-exception
 #include <config.h>
 
 #include <dune/common/test/testsuite.hh>
@@ -178,6 +180,49 @@ int main()
       << "Counting all nodes with forEachNode failed. Result is " << all << " but should be " << 6;
   }
 
+  {
+    std::size_t all = 0;
+    auto countNode = [&](auto&& node, auto&& path) {
+      ++all;
+    };
+    auto nop = [&](auto&& node, auto&& path) {};
+    forEachNode(tree, countNode, countNode, nop);
+    test.check(all==6)
+      << "Counting all nodes with forEachNode failed. Result is " << all << " but should be " << 6;
+  }
+
+  {
+    std::size_t all = 0;
+    auto countNode = [&](auto&& node, auto&& path) {
+      ++all;
+    };
+    auto nop = [&](auto&& node, auto&& path) {};
+    forEachNode(tree, nop, countNode, countNode);
+    test.check(all==6)
+      << "Counting all nodes with forEachNode failed. Result is " << all << " but should be " << 6;
+  }
+
+  {
+    std::size_t all = 0;
+    auto countNode = [&](auto&& node, auto&& path) {
+      ++all;
+    };
+    auto nop = [&](auto&& node, auto&& path) {};
+    forEachNode(tree, nop, countNode, nop);
+    test.check(all==4)
+      << "Counting all nodes with forEachNode failed. Result is " << all << " but should be " << 4;
+  }
+
+  {
+    std::size_t all = 0;
+    auto countNode = [&](auto&& node, auto&& path) {
+      ++all;
+    };
+    forEachNode(tree, countNode, countNode, countNode);
+    test.check(all==8)
+      << "Counting all nodes with forEachNode failed. Result is " << all << " but should be " << 8;
+  }
+
   {
     std::size_t inner = 0;
     std::size_t leaf = 0;
